import AuthProvider from "./auth-provider";
interface Auth {
    userLogin(username: string, password: string, email?: string): Promise<string>;
    userAdd(username: string, password: string, email?: string): Promise<string>;
    userRemove(username: string, password: string): Promise<boolean>;
    userLogout(token: string): Promise<void>;
    shouldBeAbleTo(accessType: AccessType, packageName: string, accessToken: string): Promise<boolean>;
    verifyLogin(username: string, password: string): Promise<string>;
    verifyToken(token: string): Promise<string>;
}
declare class AuthManager implements Auth {
    private readonly dbLocation;
    private settings;
    private adapter;
    private readonly tokens;
    constructor(adapter: AuthProvider, config: Map<string, any>);
    userLogin(username: string, password: string, email?: string): Promise<string>;
    userAdd(username: string, password: string, email?: string): Promise<string>;
    userRemove(username: string, password: string): Promise<boolean>;
    userLogout(token: string): Promise<void>;
    shouldBeAbleTo(accessType: AccessType, packageName: string, accessToken: string): Promise<boolean>;
    verifyLogin(username: string, password: string): Promise<string>;
    verifyToken(token: string): Promise<string>;
}
declare enum AccessType {
    Access = 0,
    Publish = 1
}
interface IAuthSettings {
    adapter: string;
    users: {
        canPublish: boolean;
        canAccess: boolean;
    };
    register: boolean;
    public: boolean;
    remove: boolean;
}
export default Auth;
export { Auth, AccessType, IAuthSettings, AuthManager };
