"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
class AuthManager {
    constructor(adapter, config) {
        this.dbLocation = path_1.join(config.get("workDir"), "db");
        this.tokens = new Map();
        this.settings = config.get("auth");
        this.adapter = adapter;
    }
    userLogin(username, password, email) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.adapter.userLogin(username, password, email);
            }
            catch (err) { }
            throw Error("Unauthorized");
        });
    }
    userAdd(username, password, email) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.adapter.userAdd(username, password, email ? email : "");
            }
            catch (err) { }
            throw Error("Unauthorized");
        });
    }
    userRemove(username, password) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.settings.remove === false) {
                return false;
            }
            try {
                return yield this.adapter.userRemove(username, password);
            }
            catch (err) {
                return false;
            }
        });
    }
    userLogout(token) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.adapter.userLogout(token);
        });
    }
    shouldBeAbleTo(accessType, packageName, accessToken) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.settings.public === true) {
                return true;
            }
            accessToken = accessToken.substr(7);
            const usersSettings = this.settings.users;
            if (accessType === AccessType.Access && usersSettings.canAccess === true) {
                try {
                    return (typeof (yield this.adapter.verifyToken(accessToken)) === "string");
                }
                catch (err) {
                    return false;
                }
            }
            if (accessType === AccessType.Publish &&
                usersSettings.canPublish === true) {
                try {
                    return (typeof (yield this.adapter.verifyToken(accessToken)) === "string");
                }
                catch (err) {
                    return false;
                }
            }
            throw new Error("Unauthorized");
        });
    }
    verifyLogin(username, password) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.adapter.userLogin(username, password);
            }
            catch (err) { }
            throw Error("Unauthorized");
        });
    }
    verifyToken(token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return yield this.adapter.verifyToken(token);
            }
            catch (err) { }
            throw Error("Unauthorized");
        });
    }
}
exports.AuthManager = AuthManager;
var AccessType;
(function (AccessType) {
    AccessType[AccessType["Access"] = 0] = "Access";
    AccessType[AccessType["Publish"] = 1] = "Publish";
})(AccessType || (AccessType = {}));
exports.AccessType = AccessType;
//# sourceMappingURL=index.js.map