"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const init_1 = require("./init");
const fs = require("async-file");
const path = require("path");
const process = require("process");
function serveAction(config) {
    if (typeof config === "string") {
        fs.exists(config).then((result) => {
            if (!result) {
                throw Error(`Config file: ${config} does not exist`);
            }
            fs.readFile(config).then((file) => {
                const container = init_1.default(JSON.parse(file));
                const logger = container.get("logger");
                logger.info("using config: " + config + "\n");
                const command = container.get("command-serve");
                command.run().then(() => 0);
            });
        });
    }
    else {
        const configLocation = path.join(__dirname, "../", "config.json");
        fs.readFile(configLocation).then((file) => {
            const container = init_1.default(JSON.parse(file));
            const logger = container.get("logger");
            logger.info("using default config\n");
            const command = container.get("command-serve");
            command.run().then(() => 0);
        });
    }
}
exports.serveAction = serveAction;
function initAction() {
    const configLocation = path.join(__dirname, "../", "config.json");
    fs.readFile(configLocation).then((file) => {
        const container = init_1.default(JSON.parse(file));
        const command = container.get("command-init");
        command.run(process.cwd());
    });
}
exports.initAction = initAction;
commander
    .command("serve")
    .alias("s")
    .description("serve ap-npm")
    .option("-c, --config", "config file to use", "")
    .action(serveAction);
commander
    .command("init")
    .description("init a npm project using ap-npm publishConfig")
    .action(initAction);
commander
    .command("version")
    .alias("v")
    .action(function () {
    const configLocation = path.join(__dirname, "../", "config.json");
    fs.readFile(configLocation).then((file) => {
        const logger = init_1.default(JSON.parse(file)).get("logger");
        fs.readFile(path.join(__dirname, "../package.json")).then((file) => {
            logger.log(JSON.parse(file).version);
        });
    });
});
commander.parse(process.argv);
if (!process.argv.slice(2).length) {
    commander.outputHelp();
}
//# sourceMappingURL=cli.js.map