"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("async-file");
const child_process = require("child_process");
const path = require("path");
class InitCommand {
    constructor(config, logger) {
        this.host = config.get("hostname");
        this.port = config.get("port");
        this.ssl = config.get("ssl").enabled;
        this.logger = logger;
    }
    run(pathToProject) {
        return __awaiter(this, void 0, void 0, function* () {
            const spawn = child_process.spawnSync;
            const shell = (cmd, opts) => {
                process.stdin.pause();
                return spawn(cmd, opts, {
                    stdio: [0, 1, 2]
                });
            };
            yield shell("npm", ["init"]);
            const file = yield fs.readFile(path.join(pathToProject, "package.json"));
            let publishConfig;
            if (this.ssl) {
                publishConfig = {
                    registry: "https://" + this.host + ":" + this.port
                };
            }
            else {
                publishConfig = {
                    registry: "http://" + this.host + ":" + this.port
                };
            }
            this.logger.info("\nUpdating package.json with publishConfig:", publishConfig);
            const packageJson = JSON.parse(file);
            packageJson.publishConfig = publishConfig;
            yield fs.writeFile(path.join(pathToProject, "package.json"), JSON.stringify(packageJson, undefined, 2), { mode: "0664" });
            this.logger.info("ap-npm project created in: " + pathToProject + "\n");
        });
    }
}
exports.default = InitCommand;
//# sourceMappingURL=init.js.map