"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Https = require("https");
const fs = require("async-file");
class ServeCommand {
    constructor(server, config, logger) {
        this.app = server;
        this.port = config.get("port");
        this.ssl = config.get("ssl");
        this.hostname = config.get("hostname");
        this.config = config;
        this.logger = logger;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.ssl.enabled) {
                if ((yield fs.exists(this.ssl.key)) && (yield fs.exists(this.ssl.cert))) {
                    const key = yield fs.readFile(this.ssl.key);
                    const cert = yield fs.readFile(this.ssl.cert);
                    Https.createServer({
                        key: key,
                        cert: cert
                    }, this.app).listen(this.port, this.hostname, () => {
                        this.logger.info("ap-npm is listening on " + this.hostname + ":" + this.port + "\n");
                    });
                }
                else {
                    this.config.get("ssl").enabled = false;
                    this.logger.warn("ssl setup failed, key/cert files don't exist\n" +
                        "ap-npm will run without being accessible using ssl\n");
                    this.logger.info(`ap-npm is listening on http://${this.hostname}:${this.port}\n`);
                    this.app.listen(this.port);
                }
            }
            else {
                this.logger.info(`ap-npm is listening on http://${this.hostname}:${this.port}\n`);
                this.app.listen(this.port);
            }
        });
    }
}
exports.default = ServeCommand;
//# sourceMappingURL=serve.js.map