"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const routes_1 = require("../routes");
const auth_1 = require("../auth");
const json_provider_1 = require("../auth/json-provider");
const validator_1 = require("../util/validator");
const logger_1 = require("../util/logger");
const axios = require("@contentful/axios");
const Process = require("process");
const fs = require("async-file");
function default_1(container) {
    container.set("fs", function () {
        return fs;
    });
    container.set("express", function () {
        const app = express();
        routes_1.default(app, container);
        app.set("env", process.env.NODE_ENV || "production");
        return app;
    });
    container.set("validator", function () {
        return new validator_1.default(container.get("storage"));
    });
    container.set("auth", function () {
        return new auth_1.AuthManager(container.get("auth-adapter"), container.get("config"));
    });
    container.set("auth-adapter", function () {
        if (container.get("config").get("auth").adapter === "default") {
            return new json_provider_1.default(container.get("config"), container.get("fs"));
        }
        const authAdapter = require(container.get("config").get("auth").adapter).default;
        return new authAdapter(container.get("config"));
    });
    container.set("axios", function () {
        return axios;
    });
    container.set("logger", function () {
        return new logger_1.default(Process.stdout);
    });
}
exports.default = default_1;
//# sourceMappingURL=util-init.js.map