"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bodyParser = require("body-parser");
const access_1 = require("./auth/access");
const auth_1 = require("./auth");
function InitRoutes(app, container) {
    const config = container.get("config");
    const access = new access_1.default(container.get("auth"), config.get("auth").public);
    const logger = container.get("logger");
    app.use((req, res, next) => {
        logger.log(`\nMETHOD: ${req.method}, URL: ${decodeURIComponent(req.originalUrl)}\n`);
        next();
    });
    app.use(bodyParser.json({ strict: false, limit: "10mb" }));
    app.get("/-/ping", (req, res) => {
        res.send({
            message: "ap-npm is running"
        });
    });
    app.get("/api/authenticate", (req, res) => {
        const route = container.get("route-api-authenticate");
        return route.process(req, res);
    });
    app.get("/api/packages", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-api-package");
        return route.process(req, res);
    });
    app.get("/api/package/:package?", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-api-package");
        return route.process(req, res);
    });
    app.get("/api/package/:scope%2f:package", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-api-package");
        return route.process(req, res);
    });
    app.get("/:scope%2f:package", access.can(auth_1.AccessType.Publish), (req, res, next) => {
        if (req.query.write === "true") {
            const route = container.get("route-package-delete");
            return route.process(req, res);
        }
        else {
            next();
        }
    });
    app.get("/:package", access.can(auth_1.AccessType.Publish), (req, res, next) => {
        if (req.query.write === "true") {
            const route = container.get("route-package-delete");
            return route.process(req, res);
        }
        else {
            next();
        }
    });
    app.get("/-/v1/search", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-search");
        return route.process(req, res);
    });
    app.post("/-/v1/login", (req, res) => {
        const route = container.get("route-auth-user-login");
        return route.process(req, res);
    });
    app.put("/-/user/org.couchdb.user:_rev?/:revision?", (req, res) => {
        const route = container.get("route-auth-user-login");
        return route.process(req, res);
    });
    app.delete("/-/user/token/:token?", (req, res) => {
        const route = container.get("route-auth-user-logout");
        return route.process(req, res);
    });
    app.get("/whoami", (req, res) => {
        const route = container.get("route-auth-whoami");
        return route.process(req, res);
    });
    app.get("/-/whoami", (req, res) => {
        const route = container.get("route-auth-whoami");
        return route.process(req, res);
    });
    app.get("/:scope%2f:package/:version?", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get-json");
        return route.process(req, res);
    });
    app.get("/:package/:version?", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get-json");
        return route.process(req, res);
    });
    app.get("/:scope%2f:package/-/:filename", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get");
        return route.process(req, res);
    });
    app.get('/:this.config.get("auth")ge/-/:filename', access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get");
        return route.process(req, res);
    });
    app.get("/-/package/:scope%2f:package/dist-tags", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get-dist-tags");
        return route.process(req, res);
    });
    app.get("/-/package/:package/dist-tags", access.can(auth_1.AccessType.Access), (req, res) => {
        const route = container.get("route-package-get-dist-tags");
        return route.process(req, res);
    });
    app.delete("/-/package/:scope%2f:package/dist-tags/:tag", access.can(auth_1.AccessType.Publish), (req, res) => {
        const route = container.get("route-package-delete-dist-tags");
        return route.process(req, res);
    });
    app.delete("/-/package/:package/dist-tags/:tag", access.can(auth_1.AccessType.Publish), (req, res) => {
        const route = container.get("route-package-delete-dist-tags");
        return route.process(req, res);
    });
    app.put("/-/package/:scope%2f:package/dist-tags/:tag", access.can(auth_1.AccessType.Publish), (req, res) => {
        const route = container.get("route-package-add-dist-tags");
        return route.process(req, res);
    });
    app.put("/-/package/:package/dist-tags/:tag", access.can(auth_1.AccessType.Publish), (req, res) => {
        const route = container.get("route-package-add-dist-tags");
        return route.process(req, res);
    });
    app.put("/:scope%2f:package/:_rev?/:revision?", access.can(auth_1.AccessType.Publish), (req, res) => {
        const route = container.get("route-package-publish");
        return route.process(req, res);
    });
    app.put("/:package/:_rev?/:revision?", access.can(auth_1.AccessType.Publish), (req, res) => {
        logger.info("PackagePublish");
        const route = container.get("route-package-publish");
        return route.process(req, res);
    });
    app.post("/-/npm/v1/security/audits", (req, res) => {
        const route = container.get("route-audit-proxy");
        return route.process(req, res);
    });
    app.post("/-/npm/v1/security/audits/quick", (req, res) => {
        const route = container.get("route-audit-proxy");
        return route.process(req, res);
    });
    app.get("/", (req, res) => {
        if (req.url === "/" || req.url === "") {
            res.send("ap-npm is running\n");
        }
    });
    return app;
}
exports.default = InitRoutes;
//# sourceMappingURL=routes.js.map