"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const semver = require("semver");
const route_1 = require("./route");
class PackageDelete extends route_1.default {
    constructor(storage, validator, config) {
        super();
        this.storage = storage;
        this.packageValidator = validator;
        this.config = config;
        if (this.config.has("auth")) {
            this.remove = this.config.get("auth").remove;
        }
        else {
            this.remove = false;
        }
    }
    process(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.remove !== true) {
                res.status(403).send({ message: "Not allowed to delete packages" });
                return;
            }
            const packageName = req.params.package;
            const packageScope = req.params.scope;
            if (!req.headers.referer) {
                res.status(400).send({ message: "No referer given" });
                return;
            }
            let packageVersion = undefined;
            const referer = Array.isArray(req.headers.referer)
                ? String(req.headers.referer[0])
                : String(req.headers.referer);
            const slices = referer.split(" ");
            if (slices.length < 2) {
                res.status(400).send({ ok: false, message: "Invalid referer" });
                return;
            }
            const command = slices[0];
            if (command !== "unpublish") {
                res
                    .status(400)
                    .send({ ok: false, message: `Unknown command ${command}` });
                return;
            }
            if (slices[1].indexOf("@") > -1) {
                const pkgSlices = slices[1].split("@");
                packageVersion = pkgSlices[1];
            }
            if (packageVersion !== undefined && semver.valid(packageVersion)) {
                try {
                    if (yield this.storage.removePackageVersion({
                        name: packageName,
                        scope: packageScope,
                        version: packageVersion
                    })) {
                        res
                            .status(200)
                            .send({
                            ok: true,
                            message: `Package version: ${packageVersion} deleted`
                        });
                        return;
                    }
                }
                catch (err) { }
            }
            else {
                try {
                    if (yield this.storage.removePackage({
                        name: packageName,
                        scope: packageScope
                    })) {
                        res.status(200).send({ ok: true, message: "Package deleted" });
                        return;
                    }
                }
                catch (err) { }
            }
            res
                .status(500)
                .send({ ok: false, message: "Cannot delete package from filesystem" });
        });
    }
}
exports.default = PackageDelete;
//# sourceMappingURL=package-delete.js.map