"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const route_1 = require("./route");
class PackagePublish extends route_1.default {
    constructor(storage, validator) {
        super();
        this.storage = storage;
        this.packageValidator = validator;
    }
    process(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const packageData = req.body;
            const packageName = req.params.package;
            const packageScope = req.params.scope;
            if (!packageData._attachments) {
                const result = yield this.storage.updatePackageJson({ name: packageName, scope: packageScope }, packageData);
                if (result === true) {
                    res.status(200).send({ ok: "package.json updated" });
                    return;
                }
                else {
                    res.status(500).send({ message: "Error, cannot update package.json" });
                    return;
                }
            }
            const available = yield this.storage.isPackageAvailable({
                name: packageName,
                scope: packageScope
            });
            if (available) {
                yield this.writePackage({ name: packageName, scope: packageScope }, req, res);
            }
            else {
                yield this.writeNewPackage({ name: packageName, scope: packageScope }, req, res);
            }
        });
    }
    writePackage(pkg, req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const keys = Object.keys(req.body["dist-tags"] ? req.body["dist-tags"] : {});
            if (keys.length === 0) {
                res
                    .status(400)
                    .send({ ok: false, message: "Invalid request, no dist-tag given" });
                return;
            }
            const distTag = keys[0];
            const packageData = req.body;
            const hasDistTag = yield this.packageValidator.hasDistTag(pkg, distTag);
            if (hasDistTag === true) {
                const result = yield this.packageValidator.isVersionHigher(Object.assign({}, pkg, { version: packageData["dist-tags"][distTag] }), distTag);
                if (result === false) {
                    res.status(400).send({
                        message: "Cannot publish, given version already exists or is invalid"
                    });
                }
                else {
                    try {
                        if (yield this.storage.writePackage(pkg, packageData)) {
                            res.status(201).send({ ok: true, message: "Package published" });
                            return;
                        }
                    }
                    catch (err) { }
                    res.status(500).send({ ok: false, message: "Error while writing package" });
                }
            }
            else {
                res.status(400).send({
                    message: "Cannot publish, given version already exists or is invalid"
                });
            }
        });
    }
    writeNewPackage(pkg, req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (yield this.storage.writeNewPackage(pkg, req.body)) {
                    res.status(201).send({ ok: true, message: "package published" });
                    return;
                }
            }
            catch (err) { }
            res.status(500).send({ ok: false, message: "Error while writing package" });
        });
    }
}
exports.default = PackagePublish;
//# sourceMappingURL=package-publish.js.map