"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const route_1 = require("./route");
class Search extends route_1.default {
    constructor(storage) {
        super();
        this.storage = storage;
    }
    process(req, res) {
        return __awaiter(this, void 0, void 0, function* () {
            const query = typeof req.query.text === "string" ? req.query.text : "";
            const size = req.query.size ? req.query.size : 20;
            const listing = yield this.storage.getPackageListing();
            const objects = [];
            for (const [k, v] of listing) {
                if (objects.length >= size)
                    break;
                if (k.startsWith("@")) {
                    for (const scopedK of Object.keys(v)) {
                        if (objects.length >= size)
                            break;
                        if (scopedK.indexOf(query) <= -1) {
                            continue;
                        }
                        const pkgJson = yield this.storage.getPackageJson({
                            name: scopedK,
                            scope: k
                        });
                        objects.push({
                            "package": {
                                name: scopedK,
                                scope: k,
                                author: pkgJson.author,
                                version: pkgJson["dist-tags"]["latest"],
                                description: pkgJson.description,
                                keyword: pkgJson.keywords ? pkgJson.keywords : []
                            },
                            score: {},
                            searchScore: 1
                        });
                    }
                }
                else {
                    if (k.indexOf(query) <= -1) {
                        continue;
                    }
                    const pkgJson = yield this.storage.getPackageJson({
                        name: k
                    });
                    objects.push({
                        "package": {
                            name: k,
                            scope: "unscoped",
                            version: pkgJson["dist-tags"]["latest"],
                            description: pkgJson.description,
                            keyword: pkgJson.keywords ? pkgJson.keywords : []
                        },
                        score: {},
                        searchScore: 1
                    });
                }
            }
            res.status(200).send({ objects: objects });
        });
    }
}
exports.default = Search;
//# sourceMappingURL=search.js.map