"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const remove_package_1 = require("./utils/remove-package");
const remove_package_version_1 = require("./utils/remove-package-version");
const get_package_1 = require("./utils/get-package");
const get_package_json_1 = require("./utils/get-package-json");
const is_package_available_1 = require("./utils/is-package-available");
const update_packagejson_1 = require("./utils/update-packagejson");
const write_package_1 = require("./utils/write-package");
const write_new_package_1 = require("./utils/write-new-package");
const get_package_listing_1 = require("./utils/get-package-listing");
class Filesystem {
    constructor(config, logger, fs) {
        this.config = config;
        this.logger = logger;
        this.fs = fs;
        this.storageLocation = path.join(this.config.get("workDir"), this.config.get("storage").directory);
        fs.exists(this.storageLocation)
            .then(result => {
            if (result !== true) {
                return fs.createDirectory(this.storageLocation).then(() => { });
            }
        })
            .catch(err => {
            logger.error(`Failed to initialize filesystem-structure in ${this.storageLocation}`, err);
        })
            .then(() => { });
    }
    removePackage(request) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield remove_package_1.default(this.fs, request, this.storageLocation);
        });
    }
    removePackageVersion(request) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield remove_package_version_1.default(this.fs, request, this.storageLocation, this.getPackageJson, this.removePackage, this.updatePackageJson);
        });
    }
    writeNewPackage(request, packageData) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield write_new_package_1.default(this.fs, request, packageData, this.storageLocation, this.logger);
        });
    }
    writePackage(request, packageData) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield write_package_1.default(this.fs, request, packageData, this.storageLocation, this.logger);
        });
    }
    getPackage(request) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield get_package_1.default(this.fs, request, this.storageLocation);
        });
    }
    getPackageJson(request) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield get_package_json_1.default(this.fs, request, this.storageLocation);
        });
    }
    isPackageAvailable(request) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield is_package_available_1.default(this.fs, request, this.storageLocation);
        });
    }
    updatePackageJson(request, packageJson) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield update_packagejson_1.default(this.fs, request, packageJson, this.storageLocation);
        });
    }
    getPackageListing() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield get_package_listing_1.default(this.fs, this.storageLocation);
        });
    }
}
exports.default = Filesystem;
//# sourceMappingURL=index.js.map