"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const semver = require("semver");
exports.default = (fs, request, storageLocation, getPackageJson, removePackage, updatePackageJson) => __awaiter(this, void 0, void 0, function* () {
    const packageName = request.name;
    const packageScope = request.scope;
    const packageVersion = request.version;
    const packageLocation = packageScope
        ? path_1.join(storageLocation, packageScope, packageName)
        : path_1.join(storageLocation, packageName);
    const tarballLocation = path_1.join(packageLocation, packageName + packageVersion + ".tgz");
    const pkgExists = yield fs.exists(tarballLocation);
    if (!pkgExists) {
        throw Error("Version does not exist");
    }
    yield fs.unlink(tarballLocation);
    const packageJson = yield getPackageJson(request);
    if (packageVersion) {
        delete packageJson.versions[packageVersion];
    }
    if (Object.keys(packageJson.versions).length === 0) {
        yield removePackage(request);
        return true;
    }
    if (packageJson["dist-tags"].latest === packageVersion) {
        let highestVersion = undefined;
        Object.keys(packageJson.versions).forEach((key) => {
            if (highestVersion === undefined) {
                highestVersion = key;
            }
            else {
                if (semver.satisfies(key, ">" + highestVersion)) {
                    highestVersion = key;
                }
            }
        });
        packageJson["dist-tags"].latest = highestVersion;
    }
    return yield updatePackageJson(request, packageJson);
});
//# sourceMappingURL=remove-package-version.js.map