"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const semver_1 = require("semver");
exports.default = (fs, request, packageData, storageLocation, logger) => __awaiter(this, void 0, void 0, function* () {
    const packageName = request.name;
    const packageScope = request.scope;
    let keys = Object.keys(packageData._attachments);
    if (keys.length === 0) {
        throw Error("Invalid attachment");
    }
    const attachmentName = keys[0];
    keys = Object.keys(packageData.versions);
    if (keys.length === 0) {
        throw Error("Invalid version");
    }
    const version = yield getHighestVersion(keys);
    const folderPath = packageScope
        ? path_1.join(storageLocation, packageScope, packageName)
        : path_1.join(storageLocation, packageName);
    yield fs.createDirectory(folderPath);
    const filePath = path_1.join(folderPath, packageName + "-" + version + ".tgz");
    const packageJsonPath = path_1.join(folderPath, "package.json");
    const packageJson = JSON.parse(JSON.stringify(packageData));
    delete packageJson._attachments;
    try {
        yield Promise.all([
            fs.writeFile(filePath, Buffer.from(packageData._attachments[attachmentName].data, "base64"), { mode: "0777" }),
            fs.writeFile(packageJsonPath, JSON.stringify(packageJson))
        ]);
    }
    catch (err) {
        logger.error("Error writing package: ", err);
        return false;
    }
    if (packageScope) {
        logger.info(`Published package: ${packageScope}/${packageName}`);
    }
    else {
        logger.info(`Published package: ${packageName}`);
    }
    return true;
});
function getHighestVersion(keys) {
    return __awaiter(this, void 0, void 0, function* () {
        let highest = keys[0];
        keys.forEach((v) => {
            if (semver_1.satisfies(v, ">" + highest)) {
                highest = v;
            }
        });
        return highest;
    });
}
//# sourceMappingURL=write-new-package.js.map