"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const semver_1 = require("semver");
exports.default = (fs, request, packageData, storageLocation, logger) => __awaiter(this, void 0, void 0, function* () {
    const packageName = request.name;
    const packageScope = request.scope;
    const packageInfoLocation = packageScope
        ? path_1.join(storageLocation, packageScope, packageName, "package.json")
        : path_1.join(storageLocation, packageName, "package.json");
    const folderPath = packageScope
        ? path_1.join(storageLocation, packageScope, packageName)
        : path_1.join(storageLocation, packageName);
    yield fs.createDirectory(folderPath);
    let keys = Object.keys(packageData._attachments);
    if (keys.length === 0) {
        throw Error("Invalid attachment");
    }
    const attachmentName = keys[0];
    keys = Object.keys(packageData.versions);
    if (keys.length === 0) {
        throw Error("Invalid new-version");
    }
    const newVersion = keys[0];
    const filePath = path_1.join(folderPath, packageName + "-" + newVersion + ".tgz");
    let packageJson;
    try {
        const string = yield fs.readFile(packageInfoLocation);
        packageJson = JSON.parse(string);
    }
    catch (err) {
        return false;
    }
    if (!semver_1.valid(newVersion)) {
        throw Error("Invalid new version");
    }
    packageJson.versions[newVersion] = packageData.versions[newVersion];
    const distTags = packageJson["dist-tags"];
    const newDistTags = packageData["dist-tags"];
    yield Promise.all(Object.keys(newDistTags)
        .map((k) => __awaiter(this, void 0, void 0, function* () {
        distTags[k] = newDistTags[k];
    })));
    packageJson["dist-tags"] = distTags;
    try {
        yield Promise.all([
            fs.writeFile(packageInfoLocation, JSON.stringify(packageJson)),
            fs.writeFile(filePath, Buffer.from(packageData._attachments[attachmentName].data, "base64"), { mode: "0777" })
        ]);
    }
    catch (err) {
        logger.error("Error writing package: ", err);
        return false;
    }
    if (packageScope) {
        logger.info(`Published package: ${packageScope}/${packageName}`);
    }
    else {
        logger.info(`Published package: ${packageName}`);
    }
    return true;
});
//# sourceMappingURL=write-package.js.map